SystemOrganization addCategory: #'Pier-ScriptingAPI'!
SystemOrganization addCategory: #'Pier-ScriptingAPI-Scalability'!

!WADispatcher methodsFor: '*pier-scriptingapi' stamp: 'kph 9/15/2006 04:03'!
allApplications

| apps |

 apps := self entryPoints select: [ :ep | ep isApplication ].

self entryPoints select: [ :ep | ep isDispatcher ] thenDo: [:ep | apps addAll: ep allApplications ].

^apps

 ! !

Object subclass: #PRModelScripter
	instanceVariableNames: 'kernel'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pier-ScriptingAPI'!

!PRModelScripter commentStamp: '<historical>' prior: 0!
Implementing the same protocol as PRCommandScripter. PRModelScripter is simple programmatic interface to Pier which operates on the model directly.

If you wish to use PRModelScripter to load a Magma persisted model then you have to provide the MagmaSession, manage transactions, and explicitly instanciate PRModelScripter on the persisted kernel instance obtained from '(aMagmaSession root store at: 'pier') kernel'. see #exampleMagmaUsage.

(PRModelScripter onKernelNamed: 'pier') addPageAt: '/' name: 'testing123' contents: 'testing 1.2.3..'.
(PRModelScripter onKernelNamed: 'pier') 

(PRTimingWrapper on: (PRModelScripter onKernelNamed: 'pier')) addPageAt: '/' name: 'testing123' contents: 'testing 1.2.3..'.
(PRTimingWrapper on: (PRModelScripter onKernelNamed: 'pier')) removePageAt: '/testing123'.!

PRModelScripter subclass: #PRCommandScripter
	instanceVariableNames: 'logging'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pier-ScriptingAPI'!

!PRCommandScripter commentStamp: '<historical>' prior: 0!
PRCommandScripter a simple programmatic interface to Pier, which uses the PRCommand mechanism to interface with the model. 

This means that all actions may be logged as if made through the Seaside interface. 

Logging can be turned on/off with #noLog #yesLog. If logging is disabled then the PRCommandScripter should be equivalent to PRModelScriptor but with an implementation more consistent with the end user experience (i.e. validation provided by PRCommands etc.). 

PRModelScriptor provides examples of how the Model may be used but PRCommandScriptor is the preferred interface to command functions. 

Note: Care is taken in the the PRCommandScripter API to explicitly ensure that an instance keeps no references to the model, or commands onto the model, in local instance varsiable. This is so as not to become a potential garbage collection inhibiting 'hard ref' to the model.
!

PRCommandScripter subclass: #PRCommandAppScripter
	instanceVariableNames: 'session'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pier-ScriptingAPI'!

!PRCommandAppScripter commentStamp: '<historical>' prior: 0!
PRCommandAppScripter provides a scripting interface which executes its commands in the context of a registered seaside application.

The aim of this interface is to ensure that 'WACurrentSession value' returns a useful result when running scripts. PRMagmaPersistency uses 'WACurrentSession value', and command actions should result in the persistent store being updated just as when executed through the seaside user interface.

usage:

PRCommandAppScripter kernelNamed: 'pier'  
searches for the first application whose configuration entry #kernelName matches the requested name. A session is created using the configuration settings of this application. 

caveat: if you have more than one application serving the same pier kernel with different preferences you have been warned. If no application is found, it will fallback to use any application that is serving all kernels (#mainClass is set to PRMainAllKernels). If you have more than one of these serving more than one repository then it will not check to ensure that it has the correct repository.

PRCommandAppScripter onApp: 'st'
explicitly gives entry point for the application in whose context the scripts are to be run. It is assumed that the value of #kernelName is valid. For an application using PRMainAllKernels, use #onApp:onKernelName: to explicitly target the required kernel.

!

!PRCommandAppScripter class methodsFor: 'as yet unclassified' stamp: 'kph 9/18/2006 02:54'!
findAppServingAllKernels

^WADispatcher default allApplications detect: [ :app |
					(app preferenceAt: #mainClass) respondsTo: #isServingAllKernels ]
			 ! !

!PRCommandAppScripter class methodsFor: 'as yet unclassified' stamp: 'kph 9/29/2006 05:39'!
findAppServingKernel: requestedKernelName ifNone: notThereBlock

^WADispatcher default allApplications detect: [ :app |
					(app preferenceAt: #kernel) name = requestedKernelName ] 
	ifNone: notThereBlock ! !

!PRCommandAppScripter class methodsFor: 'as yet unclassified' stamp: 'kph 9/29/2006 05:38'!
onApp: entryPointName

| application sessionClass kernel |

application :=  WADispatcher default entryPointAt: entryPointName.
sessionClass := application preferenceAt: #sessionClass.
kernel  := application preferenceAt: #kernel.

^self new
	setSession: (sessionClass application: application); 
	setKernel: kernel;
	yourself
! !

!PRCommandAppScripter class methodsFor: 'as yet unclassified' stamp: 'kph 9/28/2006 05:05'!
onApp: entryPointName kernelNamed: kernelName

| application sessionClass  |

application :=  WADispatcher default entryPointAt: entryPointName.
sessionClass := application preferenceAt: #sessionClass.

^self new 
	setSession: (sessionClass application: application); 
	setKernel: (PRKernel instanceNamed: kernelName);
	yourself
! !

!PRCommandAppScripter class methodsFor: 'as yet unclassified' stamp: 'kph 9/28/2006 05:05'!
onKernelNamed: requestedKernelName

"find a registered seaside application serving the desired kernel and make a session using the settings of that application"

| application sessionClass |

application :=  self findAppServingKernel: requestedKernelName 
					ifNone: [ self findAppServingAllKernels ].

sessionClass := application preferenceAt: #sessionClass.

^self new 
	setSession: (sessionClass application: application); 
	setKernel: (PRKernel instanceNamed: requestedKernelName);
	yourself
! !

!PRCommandAppScripter class methodsFor: 'as yet unclassified' stamp: 'kph 9/29/2006 05:40'!
onSession: aSession

^self new
	setSession: aSession;
	setKernel: (aSession application preferenceAt: #kernel);
	yourself
! !

!PRCommandAppScripter methodsFor: 'as yet unclassified' stamp: 'kph 9/16/2006 05:06'!
executeCommand: aCommand

WACurrentSession use: session during: [ super executeCommand: aCommand ].! !

!PRCommandAppScripter methodsFor: 'as yet unclassified' stamp: 'kph 9/28/2006 20:03'!
kernel

^ WACurrentSession use: session during: [ kernel realize ].! !

!PRCommandAppScripter methodsFor: 'as yet unclassified' stamp: 'kph 9/15/2006 05:08'!
session

^session! !

!PRCommandAppScripter methodsFor: 'as yet unclassified' stamp: 'kph 9/15/2006 02:40'!
setSession: aSession

session := aSession! !

!PRCommandAppScripter methodsFor: 'as yet unclassified' stamp: 'kph 10/19/2006 20:59'!
transaction: aBlock

(self session respondsTo: #magmaSession) ifFalse: [ ^ aBlock value ].

self session magmaSession stubOut: aBlock value! !

!PRCommandScripter methodsFor: 'public api' stamp: 'kph 9/17/2006 02:18'!
addPageAt: aPath name: aPageName

| aCommand |

"returns the new page added"

aCommand := PRAddCommand context: (self contextOn: aPath).
aCommand name: aPageName.
 
self executeCommand: aCommand.

^aCommand context structure childrenDecoration at: aCommand name

  ! !

!PRCommandScripter methodsFor: 'public api' stamp: 'kph 9/16/2006 05:05'!
addPageAt: aPath name: aName contents: someContent

| newPage aCommand |

newPage := self addPageAt: aPath name: aName.

aCommand := PREditCommand context: (self contextOn: newPage).
aCommand 	write: someContent
			using: PRPage descriptionContents.

self executeCommand: aCommand.

^newPage! !

!PRCommandScripter methodsFor: 'as yet unclassified' stamp: 'kph 10/19/2006 21:28'!
contextOn: aPathOrStructure
 
^ (PRContext kernel: self kernel structure: (self structureAt: aPathOrStructure))
	user: self kernel adminUser.
	 ! !

!PRCommandScripter methodsFor: 'public api' stamp: 'kph 9/27/2006 20:42'!
editPageAt: aPath contents: aBlockOrText

| aCommand pageContents |

"returns the new page added"

aCommand := PREditCommand context: (self contextOn: aPath).

pageContents := aBlockOrText isString 
	ifTrue: [ aBlockOrText ]
	ifFalse: [ aBlockOrText value: (aCommand readUsing: PRPage descriptionContents) ].
 
aCommand 	write: pageContents
			using: PRPage descriptionContents.

self executeCommand: aCommand.

^aCommand context structure  

  ! !

!PRCommandScripter methodsFor: 'as yet unclassified' stamp: 'kph 9/16/2006 05:03'!
executeCommand: aCommand.

self isLogging ifTrue: [ aCommand execute ] ifFalse: [ self executeCommandWithoutLogging: aCommand ].! !

!PRCommandScripter methodsFor: 'as yet unclassified' stamp: 'kph 9/28/2006 20:02'!
executeCommandWithoutLogging: aCommand

"code stolen from PRCommand and logging is commented out"

	aCommand isView
		ifTrue: [ aCommand shouldNotImplement ].
	aCommand kernel persistency doing: aCommand critical: [
		aCommand doValidate; doExecute.
		"aCommand isLogged
			ifTrue: [ aCommand doPersistency ]" ].
	aCommand doAnswer! !

!PRCommandScripter methodsFor: 'as yet unclassified' stamp: 'kph 9/15/2006 04:24'!
isLogging

^logging ifNil: [ false ]! !

!PRCommandScripter methodsFor: 'as yet unclassified' stamp: 'kph 9/15/2006 01:44'!
noLog

logging := false! !

!PRCommandScripter methodsFor: 'public api' stamp: 'kph 9/17/2006 02:18'!
removePageAt: aPath
 
self executeCommand: (PRRemoveCommand context: (self contextOn: aPath))
! !

!PRCommandScripter methodsFor: 'public api' stamp: 'kph 9/27/2006 21:08'!
viewPageAt: aPath  

| aCommand pageContents |

"returns the new page added"

aCommand := PRViewCommand context: (self contextOn: aPath).

pageContents := aCommand readUsing: PRPage descriptionContents.
 
self executeCommand: aCommand.
 
^ pageContents
  ! !

!PRCommandScripter methodsFor: 'as yet unclassified' stamp: 'kph 9/15/2006 01:44'!
yesLog

logging := true! !

!PRModelScripter class methodsFor: 'as yet unclassified' stamp: 'kph 10/8/2006 04:46'!
exampleMagmaUsage

| magmaSession scripter |

magmaSession := MagmaSession openLocal: 'magma-pier'.
magmaSession connectAs: 'model-scripter'.

scripter := PRModelScripter onKernel: (magmaSession pier at: 'Squeak') kernel.

magmaSession commit: [

	scripter addPageAt: '/' name: 'Testing PRModelScripter' contents: 'testing PRModelScripter... ok'.

].

magmaSession disconnectAndClose.! !

!PRModelScripter class methodsFor: 'as yet unclassified' stamp: 'kph 9/14/2006 23:52'!
onKernel: aKernel
 
^self new setKernel: aKernel ; yourself! !

!PRModelScripter class methodsFor: 'as yet unclassified' stamp: 'kph 9/29/2006 05:38'!
onKernelNamed: aKernelName
 
^self onKernel: (PRKernel instanceNamed: aKernelName) realize.! !

!PRModelScripter methodsFor: 'public api' stamp: 'kph 9/16/2006 01:10'!
addPageAt: aPath name: aName

^(self structureAt: aPath) addChild: (PRPage named: aName)! !

!PRModelScripter methodsFor: 'public api' stamp: 'kph 9/16/2006 01:12'!
addPageAt: aPath name: name contents: someContent

^ (self addPageAt: aPath name: name) contents: someContent! !

!PRModelScripter methodsFor: 'public api' stamp: 'kph 9/27/2006 20:42'!
editPageAt: aPath contents: aBlockOrText

| structure pageContents |

structure := self structureAt: aPath.

pageContents := aBlockOrText isString 
	ifTrue: [ aBlockOrText ]
	ifFalse: [ aBlockOrText value: structure contents ].

structure contents: pageContents.

^structure! !

!PRModelScripter methodsFor: 'compatibility' stamp: 'kph 9/15/2006 02:11'!
isLogging

^false! !

!PRModelScripter methodsFor: 'as yet unclassified' stamp: 'kph 9/15/2006 17:40'!
kernel

^ kernel! !

!PRModelScripter methodsFor: 'compatibility' stamp: 'kph 9/28/2006 19:43'!
memory
! !

!PRModelScripter methodsFor: 'compatibility' stamp: 'kph 9/15/2006 02:11'!
noLog! !

!PRModelScripter methodsFor: 'public api' stamp: 'kph 9/16/2006 01:20'!
removePageAt: aPath

 | aPage |

aPage := self structureAt: aPath.

aPage isRoot
		ifTrue: [ self error: 'Unable to remove root node.' ].

PRIncomingReferences
		from: self kernel root
		to: (aPage enumerator
			with; all; hidden;
			contents)
		do: [ :each | each target: nil ].

^ aPage remove! !

!PRModelScripter methodsFor: 'as yet unclassified' stamp: 'kph 9/15/2006 02:41'!
setKernel: aKernel

kernel := aKernel
! !

!PRModelScripter methodsFor: 'compatibility' stamp: 'kph 9/28/2006 19:38'!
ssh

! !

!PRModelScripter methodsFor: 'as yet unclassified' stamp: 'kph 9/16/2006 00:47'!
structureAt: aPathOrStructure

^aPathOrStructure isString ifTrue: [ PRPathLookup start: self kernel root path: aPathOrStructure ]
			   			  ifFalse: [ aPathOrStructure ].! !

!PRModelScripter methodsFor: 'compatibility' stamp: 'kph 9/29/2006 04:53'!
to: name do: aBlock
"compatibility with PRTimingWrapper"
aBlock value! !

!PRModelScripter methodsFor: 'public api' stamp: 'kph 9/17/2006 04:45'!
transaction: aBlock

^aBlock value! !

!PRModelScripter methodsFor: 'public api' stamp: 'kph 9/27/2006 21:09'!
viewPageAt: aPath  
 
	^(self structureAt: aPath) contents

 ! !

!PRModelScripter methodsFor: 'public api' stamp: 'kph 9/28/2006 00:03'!
withTempPageDo: aMonadicBlock

| tmpName |

tmpName := 'tmp-', 100 atRandom asString.

self addPageAt: '/' name: tmpName.

[ aMonadicBlock value: ('/',tmpName) ] 
	ensure: [ self removePageAt: tmpName ].! !

!PRModelScripter methodsFor: 'compatibility' stamp: 'kph 9/15/2006 02:11'!
yesLog! !

Object subclass: #PRPierifyToPage
	instanceVariableNames: 'target kernel'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pier-ScriptingAPI'!

!PRPierifyToPage commentStamp: '<historical>' prior: 0!
Abstract class of classes designed to load data from a datasource #target: into a pier page
Can be used with any of the Scripter interface classes
See subclasses for usage examples!

PRPierifyToPage subclass: #PRPierifySmalltalkClass
	instanceVariableNames: ''
	classVariableNames: 'Pace'
	poolDictionaries: ''
	category: 'Pier-ScriptingAPI-Scalability'!

!PRPierifySmalltalkClass commentStamp: '<historical>' prior: 0!
Example of how to use the scripting interface to import data. This class is instanciated with the data source as its target.

(PRPierifySmalltalkClass target: ProtoObject) into: (PRCommandScripter onKernelNamed: 'Squeak' ).
(PRModelScripter onKernelNamed: 'Squeak') removePageAt: 'ProtoObject'.

To create a sizeable database see class methods #example...

!

!PRPierifySmalltalkClass class methodsFor: 'as yet unclassified' stamp: 'kph 10/20/2006 05:43'!
exampleAllClasses

| model count |

count := 0.
model := (PRTimingWrapper on: (PRCommandAppScripter onKernelNamed: 'Pier')).

"Transcript show: model session magmaSession location; cr."
model noLog. 

ProtoObject allSubclassesDo: [ :theClass | 

count := count + 1.
Transcript show: count printString, ': ', theClass name; cr.
[
 
 (PRPierifySmalltalkClass target: theClass) into: model.
 (Delay forSeconds: self pace) wait.
] 
on: PRConflictingNameError do: [ :e | Transcript show: theClass name, ' already exists'; cr. ].


].

 
"
self pace: 30.
[ self exampleAllClasses ] forkAt: 15"

! !

!PRPierifySmalltalkClass class methodsFor: 'as yet unclassified' stamp: 'kph 10/20/2006 05:43'!
exampleProtoObject

| model |

model := PRTimingWrapper on: (PRCommandAppScripter onKernelNamed: 'Pier').
model noLog. 

ProtoObject in: [ :theClass | 

Transcript show: theClass name; cr.
(PRPierifySmalltalkClass target: theClass) into: model ].

"self exampleProtoObject"

! !

!PRPierifySmalltalkClass class methodsFor: 'as yet unclassified' stamp: 'kph 9/15/2006 04:38'!
pace

^Pace ifNil: [ 20 ].! !

!PRPierifySmalltalkClass class methodsFor: 'as yet unclassified' stamp: 'kph 9/15/2006 04:38'!
pace: t

Pace := t! !

!PRPierifySmalltalkClass class methodsFor: 'as yet unclassified' stamp: 'kph 9/15/2006 01:17'!
target: aClass  

^self new setTarget: aClass ; yourself! !

!PRPierifySmalltalkClass methodsFor: 'page items' stamp: 'kph 9/15/2006 03:43'!
classDescriptionToWiki: stream

stream nextPutAll: '!!Description'; cr.
stream nextPutAll: target class comment ; cr.
 

! !

!PRPierifySmalltalkClass methodsFor: 'page items' stamp: 'kph 9/15/2006 00:13'!
classSubclassesToWiki: stream.

target subclassesDo: [ :sc | stream nextPutAll: '- *', sc name, '*'; cr ]
  ! !

!PRPierifySmalltalkClass methodsFor: 'page items' stamp: 'kph 9/14/2006 23:56'!
methodSelectors: methodDictionary toWiki: stream

methodDictionary keysDo: [ :methodSelector | stream nextPutAll: '- *', methodSelector, '*'; cr ]
 
! !

!PRPierifySmalltalkClass methodsFor: 'page items' stamp: 'kph 9/15/2006 02:15'!
pageContentsOn: stream  

self classDescriptionToWiki: stream.

stream nextPut: $_; cr.

stream nextPutAll: '!!!!!!Subclasses'; cr.

self classSubclassesToWiki: stream.

stream nextPut: $_; cr.

stream nextPutAll: '!!!!!!Instance Methods'; cr.

self methodSelectors: target methodDictionary toWiki: stream.

stream nextPutAll: '!!!!!!Class Methods'; cr.

self methodSelectors: target class methodDictionary toWiki: stream.
 ! !

!PRPierifySmalltalkClass methodsFor: 'page items' stamp: 'kph 9/15/2006 04:31'!
pageName

^target name asString

 ! !

!PRPierifySmalltalkClass methodsFor: 'page items' stamp: 'kph 10/10/2006 23:31'!
parentPath

^ ( target allSuperclasses reverse) joinUsing: $/
 
"
(self target: ProtoObject) parentPath
(self target: String) parentPath
"! !

!PRPierifyToPage methodsFor: 'as yet unclassified' stamp: 'kph 10/19/2006 21:31'!
into: aScripter
 
aScripter addPageAt: (self parentPath) name: (self pageName) contents: (self pageContents).


! !

!PRPierifyToPage methodsFor: 'page items' stamp: 'kph 9/15/2006 00:09'!
pageContents
	^ String streamContents: [ :stream | self pageContentsOn: stream ].! !

!PRPierifyToPage methodsFor: 'page items' stamp: 'kph 9/15/2006 00:11'!
pageContentsOn: stream

^ self subclassResponsibility! !

!PRPierifyToPage methodsFor: 'page items' stamp: 'kph 9/15/2006 00:11'!
pageName

^ self subclassResponsibility! !

!PRPierifyToPage methodsFor: 'page items' stamp: 'kph 9/15/2006 00:12'!
parentPath

^ self subclassResponsibility! !

!PRPierifyToPage methodsFor: 'as yet unclassified' stamp: 'kph 9/15/2006 00:04'!
setTarget: aDataSource

target := aDataSource! !

Object subclass: #PRTimingWrapper
	instanceVariableNames: 'scripter output ssh'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pier-ScriptingAPI'!

!PRTimingWrapper commentStamp: 'kph 9/29/2006 04:53' prior: 0!
The output specified by #on:reportTo: is sent as strings to a collection stream using #nextPut: 
If no output is specified then PRTimingWrapper uses itself whose implementation of #nextPut: defaults to the Transcript.

usage:
(PRTimingWrapper on: (PRModelScripter onKernelNamed: 'pier')) addPageAt: '/' name: 'testing123' contents: 'testing 1.2.3..'.
(PRTimingWrapper on: (PRModelScripter onKernelNamed: 'pier')) removePageAt: '/testing123'.

usage:

| scripter |

scripter := PRTimingWrapper on: (PRModelScripter onKernelNamed: 'pier').
scripter memory.
scripter to: 'add 1000 pages' do: [
	1 to: 1000 do: [ :n | 
		scripter quietly addPageAt: '/' name: ('testing-', n asString) contents: 'testing 1.2.3..'.
	]
].
scripter memory.
scripter to: 'remove 1000 pages' do: [ 
	1 to: 1000 do: [ :n | 
		scripter quietly removePageAt: ('/testing-', n asString).
	]
].
Smalltalk garbageCollect.
scripter memory.!

!PRTimingWrapper class methodsFor: 'as yet unclassified' stamp: 'kph 9/28/2006 18:47'!
on: scripter 

| aNew |

aNew := self new.
^aNew setScripter: scripter; setOutput: aNew; yourself.
! !

!PRTimingWrapper class methodsFor: 'as yet unclassified' stamp: 'kph 9/28/2006 18:43'!
on: scripter reportTo: it
 
^self new setScripter: scripter; setOutput: it; yourself! !

!PRTimingWrapper methodsFor: 'as yet unclassified' stamp: 'kph 10/19/2006 21:35'!
doesNotUnderstand: aMessage

| result timed |

timed := Time millisecondsToRun: [ result := aMessage sendTo: scripter].
self isSsh ifFalse: [ self sendReport: (aMessage printStringLimitedTo: 80) duration: timed ].

^result! !

!PRTimingWrapper methodsFor: 'as yet unclassified' stamp: 'kph 9/28/2006 17:53'!
duration

^duration! !

!PRTimingWrapper methodsFor: 'as yet unclassified' stamp: 'kph 9/28/2006 19:34'!
isSsh

ssh ifFalse: [ ^false ].

ssh := false. 
^ true.
		! !

!PRTimingWrapper methodsFor: 'as yet unclassified' stamp: 'kph 9/28/2006 19:43'!
memory

self nextPut: SmalltalkImage current vmStatisticsReportString! !

!PRTimingWrapper methodsFor: 'as yet unclassified' stamp: 'kph 9/28/2006 19:07'!
nextPut: report

Transcript show: (report , String cr).

! !

!PRTimingWrapper methodsFor: 'as yet unclassified' stamp: 'kph 9/29/2006 04:43'!
quietly

ssh := true.
^self! !

!PRTimingWrapper methodsFor: 'as yet unclassified' stamp: 'kph 9/28/2006 19:28'!
sendReport: aMessage duration: timing

output nextPut: (timing asString, 'ms ', aMessage asString).! !

!PRTimingWrapper methodsFor: 'as yet unclassified' stamp: 'kph 9/28/2006 18:02'!
setOutput: it

output := it! !

!PRTimingWrapper methodsFor: 'as yet unclassified' stamp: 'kph 9/28/2006 19:35'!
setScripter: aScripter

ssh := false.
scripter := aScripter! !

!PRTimingWrapper methodsFor: 'as yet unclassified' stamp: 'kph 10/19/2006 20:53'!
ssh

ssh := true.
^self! !

!PRTimingWrapper methodsFor: 'as yet unclassified' stamp: 'kph 9/29/2006 04:53'!
to: aMessage do: aBlock

| timed |

timed := Time millisecondsToRun: aBlock.
self sendReport: aMessage duration: timed.
! !

SUComponent subclass: #PRPierPerformance
	instanceVariableNames: 'scripter result toDepth depth pages width path useTranscript'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pier-ScriptingAPI-Scalability'!

PRPierPerformance class
	instanceVariableNames: 'pusher'!

!PRPierPerformance commentStamp: 'kph 9/29/2006 04:19' prior: 0!
PRPierPerformance is a component, so can be run through a web browser. 
It may also be used in the image with output to the transcript via:

self runTestOnApp: 'pier'.
self runTestOnApp: 'squeak'.!

PRPierPerformance class
	instanceVariableNames: 'pusher'!

!PRPierPerformance class methodsFor: 'nil' stamp: 'kph 9/27/2006 03:52'!
canBeRoot

^true! !

!PRPierPerformance class methodsFor: 'nil' stamp: 'kph 10/20/2006 05:43'!
initialize
	" | application |
	pusher := CTPusher. Object new.
	application := self registerAsApplication: 'pier-theatre'.
	application preferenceAt: #sessionClass put: CTMagmaSharedSession.
	application libraries add: SULibrary; add: CTLibrary.
	application configuration addAncestor: PRPierConfiguration new.
	application configuration addAncestor: WAMagmaConfiguration new."! !

!PRPierPerformance class methodsFor: 'nil' stamp: 'kph 9/29/2006 03:41'!
pierScripterClass

^PRCommandAppScripter! !

!PRPierPerformance class methodsFor: 'nil' stamp: 'kph 9/27/2006 17:16'!
pusher
	^ pusher! !

!PRPierPerformance class methodsFor: 'nil' stamp: 'kph 9/29/2006 05:05'!
runTestOnApp: appName

^self basicNew initialize;
			  setScripter: (PRTimingWrapper on: (self pierScripterClass onApp: appName)); 
			  runTest;	
			  yourself

"
self runTestOnApp: 'squeak'.
"! !

!PRPierPerformance methodsFor: 'ui' stamp: 'kph 9/29/2006 04:57'!
beginAt: start

depth := 0.
width := 0.
path := start.
pages := OrderedCollection new.! !

!PRPierPerformance methodsFor: 'ui' stamp: 'kph 9/29/2006 05:08'!
contentsWithLinks

^ '-To go up *../level-', (depth - 1) asString, '*
-to go down *level-' ,  (depth + 1) asString, '*
ok.'! !

!PRPierPerformance methodsFor: 'ui' stamp: 'kph 9/28/2006 01:47'!
depth

^depth asInteger ifNil: [ self depthDefault ]! !

!PRPierPerformance methodsFor: 'ui' stamp: 'kph 9/28/2006 01:47'!
depth: d

depth := d! !

!PRPierPerformance methodsFor: 'settings' stamp: 'kph 9/28/2006 01:35'!
depthDefault

^5! !

!PRPierPerformance methodsFor: 'ui' stamp: 'kph 9/29/2006 03:38'!
initialize

	result := ValueHolder new contents: OrderedCollection new.
	result addDependent: self.

	depth := self depthDefault.

 
 ! !

!PRPierPerformance methodsFor: 'ui' stamp: 'kph 9/29/2006 04:01'!
nextDeep
 
| name |

depth := depth + 1.
name := 'level-', self depth asString.
path := path, '/', name.

^name! !

!PRPierPerformance methodsFor: 'ui' stamp: 'kph 9/28/2006 18:19'!
nextPut: timingReport

self result add: timingReport.
self result contentsChanged.

! !

!PRPierPerformance methodsFor: 'ui' stamp: 'kph 9/29/2006 04:05'!
nextWide

| name |

width := width + 1.
name := 'page-', width asString.

^name! !

!PRPierPerformance methodsFor: 'ui' stamp: 'kph 9/28/2006 18:33'!
output

^ self useTranscript ifTrue: [ self scripter ] ifFalse: [ self ]! !

!PRPierPerformance methodsFor: 'ui' stamp: 'kph 9/29/2006 03:56'!
path 

^path ifNil: [ path := '/' ].! !

!PRPierPerformance methodsFor: 'ui' stamp: 'kph 9/27/2006 17:16'!
pusher

^self class pusher! !

!PRPierPerformance methodsFor: 'ui' stamp: 'kph 9/29/2006 04:12'!
renderContentOn: html
html form: [ 
	html anchor on: #runTest of: self.
	html text: ' depth:'.
	html textInput on: #depthTo of: self.	 
 
	html heading with: 'Test Results:'.
   	html paragraph: [
		html div id: 'result'; with:  [
			self result do: [ :r | html text: r; break ].
		]
	].
].
	"html script: (html comet
		pusher: self pusher;
		connect)"! !

!PRPierPerformance methodsFor: 'ui' stamp: 'kph 9/27/2006 04:56'!
rendererClass

^WARenderCanvas! !

!PRPierPerformance methodsFor: 'ui' stamp: 'kph 9/28/2006 17:58'!
reportScripterResult

| out |

out := self scripter report.

self session log: out.

result contents add: out.
result contentsChanged.! !

!PRPierPerformance methodsFor: 'ui' stamp: 'kph 9/27/2006 19:46'!
result

^result contents! !

!PRPierPerformance methodsFor: 'ui' stamp: 'kph 9/29/2006 05:08'!
runTest

self scripter memory.

self scripter withTempPageDo: [ :start |

	self beginAt: start.

	10 timesRepeat: [ pages add: (scripter addPageAt: path name: self nextDeep contents:  self contentsWithLinks) ].
	10 timesRepeat: [ pages add: (scripter addPageAt: path name: self nextWide contents: 'testing 1.2.3...') ].
 
(Delay forSeconds: 60) wait.
	pages reverseDo: [ :page | scripter removePageAt: page ]. 
].

Smalltalk garbageCollect.
self scripter memory.
! !

!PRPierPerformance methodsFor: 'ui' stamp: 'kph 9/29/2006 03:38'!
scripter

^scripter ifNil: [ self scripterDefault ]! !

!PRPierPerformance methodsFor: 'settings' stamp: 'kph 9/29/2006 03:42'!
scripterDefault

^PRTimingWrapper on: (self class pierScripterClass onSession: self session) reportTo: self output.
! !

!PRPierPerformance methodsFor: 'ui' stamp: 'kph 9/29/2006 03:38'!
setScripter: aScripter

scripter := aScripter

 ! !

!PRPierPerformance methodsFor: 'ui' stamp: 'kph 9/28/2006 03:19'!
test: name do: block

| out |

out := name, ' ', (Time millisecondsToRun: block) asString, 'ms'.

self session log: out.

result contents add: out.
result contentsChanged.! !

!PRPierPerformance methodsFor: 'ui' stamp: 'kph 9/27/2006 05:04'!
testAdd! !

!PRPierPerformance methodsFor: 'ui' stamp: 'kph 9/29/2006 03:54'!
toDepth

^toDepth asInteger ifNil: [ self depthDefault ]! !

!PRPierPerformance methodsFor: 'ui' stamp: 'kph 9/29/2006 03:54'!
toDepth: d

toDepth := d! !

!PRPierPerformance methodsFor: 'ui' stamp: 'kph 9/27/2006 18:28'!
update: anAspect

Transcript show: self result contents; cr.
	self pusher javascript: (SUElement new
		id: 'result';
		update: self result contents)! !
PRPierPerformance initialize!
